@@ -18,7 +18,7 @@ int main(int argc, char *argv[])
             QLibraryInfo::location(QLibraryInfo::TranslationsPath));
     app.installTranslator(&qtTranslator);
 
-    qDebug () << "LANGUAGE " << QLocale::system().name();
+    //qDebug () << "LANGUAGE " << QLocale::system().name();
 
     QTranslator myappTranslator;
     myappTranslator.load(QString (":/resources/locale/qtwallet_") + QLocale::system().name());
