@@ -4,52 +4,52 @@
 <context>
     <name>CreateFieldDialog</name>
     <message>
-        <location filename="../DetailedWindow.cpp" line="1035"/>
+        <location filename="../../DetailedWindow.cpp" line="1049"/>
         <source>Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="1048"/>
+        <location filename="../../DetailedWindow.cpp" line="1062"/>
         <source>Type</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="1058"/>
+        <location filename="../../DetailedWindow.cpp" line="1072"/>
         <source>String</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="1059"/>
+        <location filename="../../DetailedWindow.cpp" line="1073"/>
         <source>Text</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="1060"/>
+        <location filename="../../DetailedWindow.cpp" line="1074"/>
         <source>Date</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="1061"/>
+        <location filename="../../DetailedWindow.cpp" line="1075"/>
         <source>Number</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="1062"/>
+        <location filename="../../DetailedWindow.cpp" line="1076"/>
         <source>Phone Number</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="1063"/>
+        <location filename="../../DetailedWindow.cpp" line="1077"/>
         <source>Password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="1064"/>
+        <location filename="../../DetailedWindow.cpp" line="1078"/>
         <source>URL</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="1069"/>
+        <location filename="../../DetailedWindow.cpp" line="1083"/>
         <source>Order</source>
         <translation type="unfinished"></translation>
     </message>
@@ -57,259 +57,259 @@
 <context>
     <name>DetailWindow</name>
     <message>
-        <location filename="../DetailedWindow.cpp" line="61"/>
+        <location filename="../../DetailedWindow.cpp" line="63"/>
         <source>Copy of </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="108"/>
+        <location filename="../../DetailedWindow.cpp" line="110"/>
         <source>Save</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="110"/>
-        <location filename="../DetailedWindow.cpp" line="725"/>
-        <location filename="../DetailedWindow.cpp" line="738"/>
+        <location filename="../../DetailedWindow.cpp" line="112"/>
+        <location filename="../../DetailedWindow.cpp" line="739"/>
+        <location filename="../../DetailedWindow.cpp" line="752"/>
         <source>Delete</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="111"/>
+        <location filename="../../DetailedWindow.cpp" line="113"/>
         <source>Change Face Pict.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="112"/>
+        <location filename="../../DetailedWindow.cpp" line="114"/>
         <source>Mirror Face Pict.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="113"/>
+        <location filename="../../DetailedWindow.cpp" line="115"/>
         <source>Change Back Pict.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="114"/>
+        <location filename="../../DetailedWindow.cpp" line="116"/>
         <source>Mirror Back Pict.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="115"/>
+        <location filename="../../DetailedWindow.cpp" line="117"/>
         <source>Delete Face Pict.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="116"/>
+        <location filename="../../DetailedWindow.cpp" line="118"/>
         <source>Delete Back Pict.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="117"/>
+        <location filename="../../DetailedWindow.cpp" line="119"/>
         <source>Modify fields</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="122"/>
+        <location filename="../../DetailedWindow.cpp" line="124"/>
         <source>New Card</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="123"/>
+        <location filename="../../DetailedWindow.cpp" line="125"/>
         <source>Edit Card</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="124"/>
+        <location filename="../../DetailedWindow.cpp" line="126"/>
         <source>New Card like this</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="125"/>
+        <location filename="../../DetailedWindow.cpp" line="127"/>
         <source>Duplicate Card</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="126"/>
+        <location filename="../../DetailedWindow.cpp" line="128"/>
         <source>Export Face Pict.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="127"/>
+        <location filename="../../DetailedWindow.cpp" line="129"/>
         <source>Export Back Pict.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="154"/>
+        <location filename="../../DetailedWindow.cpp" line="156"/>
         <source>Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="162"/>
+        <location filename="../../DetailedWindow.cpp" line="167"/>
         <source>Group Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="176"/>
+        <location filename="../../DetailedWindow.cpp" line="185"/>
         <source>Membership Info</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="177"/>
+        <location filename="../../DetailedWindow.cpp" line="186"/>
         <source>Password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="178"/>
+        <location filename="../../DetailedWindow.cpp" line="187"/>
         <source>Credit Card</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="179"/>
+        <location filename="../../DetailedWindow.cpp" line="188"/>
         <source>Bank Account</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="180"/>
+        <location filename="../../DetailedWindow.cpp" line="189"/>
         <source>Health Numbers</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="181"/>
+        <location filename="../../DetailedWindow.cpp" line="190"/>
         <source>Passport Info</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="182"/>
+        <location filename="../../DetailedWindow.cpp" line="191"/>
         <source>Note Card</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="183"/>
+        <location filename="../../DetailedWindow.cpp" line="192"/>
         <source>Car Info</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="184"/>
+        <location filename="../../DetailedWindow.cpp" line="193"/>
         <source>Cellular Phone</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="185"/>
+        <location filename="../../DetailedWindow.cpp" line="194"/>
         <source>Serial Number Software</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="186"/>
+        <location filename="../../DetailedWindow.cpp" line="195"/>
         <source>Serial Number Hardware</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="187"/>
+        <location filename="../../DetailedWindow.cpp" line="196"/>
         <source>Web site</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="188"/>
+        <location filename="../../DetailedWindow.cpp" line="197"/>
         <source>ID Card</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="189"/>
+        <location filename="../../DetailedWindow.cpp" line="198"/>
         <source>Social Security Number</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="190"/>
+        <location filename="../../DetailedWindow.cpp" line="199"/>
         <source>Email Account</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="191"/>
+        <location filename="../../DetailedWindow.cpp" line="200"/>
         <source>Driver&apos;s License</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="192"/>
+        <location filename="../../DetailedWindow.cpp" line="201"/>
         <source>Others</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="196"/>
+        <location filename="../../DetailedWindow.cpp" line="205"/>
         <source>Type</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="472"/>
-        <location filename="../DetailedWindow.cpp" line="511"/>
+        <location filename="../../DetailedWindow.cpp" line="473"/>
+        <location filename="../../DetailedWindow.cpp" line="519"/>
         <source>Click to see</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="564"/>
+        <location filename="../../DetailedWindow.cpp" line="573"/>
         <source>Card description is missing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="574"/>
+        <location filename="../../DetailedWindow.cpp" line="583"/>
         <source>Type card is missing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="723"/>
-        <location filename="../DetailedWindow.cpp" line="736"/>
+        <location filename="../../DetailedWindow.cpp" line="737"/>
+        <location filename="../../DetailedWindow.cpp" line="750"/>
         <source>Edit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="724"/>
-        <location filename="../DetailedWindow.cpp" line="737"/>
+        <location filename="../../DetailedWindow.cpp" line="738"/>
+        <location filename="../../DetailedWindow.cpp" line="751"/>
         <source>Mirror</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="728"/>
+        <location filename="../../DetailedWindow.cpp" line="742"/>
         <source>Export Face</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="741"/>
+        <location filename="../../DetailedWindow.cpp" line="755"/>
         <source>Export Back</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="759"/>
+        <location filename="../../DetailedWindow.cpp" line="773"/>
         <source>Choose card face image file</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="761"/>
-        <location filename="../DetailedWindow.cpp" line="899"/>
+        <location filename="../../DetailedWindow.cpp" line="775"/>
+        <location filename="../../DetailedWindow.cpp" line="913"/>
         <source>Images (*.png);;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="773"/>
+        <location filename="../../DetailedWindow.cpp" line="787"/>
         <source>Choose card face image</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="775"/>
-        <location filename="../DetailedWindow.cpp" line="914"/>
+        <location filename="../../DetailedWindow.cpp" line="789"/>
+        <location filename="../../DetailedWindow.cpp" line="928"/>
         <source>Images (*.png *.jpg *.gif *.jpeg);;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="897"/>
+        <location filename="../../DetailedWindow.cpp" line="911"/>
         <source>Choose card back image file</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="912"/>
+        <location filename="../../DetailedWindow.cpp" line="926"/>
         <source>Choose card back image</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../DetailedWindow.cpp" line="952"/>
+        <location filename="../../DetailedWindow.cpp" line="966"/>
         <source>Are you sure you want to discard changes?</source>
         <translation type="unfinished"></translation>
     </message>
@@ -317,32 +317,47 @@
 <context>
     <name>LoginDialog</name>
     <message>
-        <location filename="../LoginDialog.cpp" line="39"/>
+        <location filename="../../LoginDialog.cpp" line="94"/>
         <source>Ok</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../LoginDialog.cpp" line="67"/>
+        <location filename="../../LoginDialog.cpp" line="102"/>
         <source>Clear</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../LoginDialog.cpp" line="174"/>
+        <location filename="../../LoginDialog.cpp" line="146"/>
+        <source>About</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../LoginDialog.cpp" line="154"/>
+        <source>Donate</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../LoginDialog.cpp" line="162"/>
+        <source>Exit</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../LoginDialog.cpp" line="218"/>
         <source>About Wallet</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../LoginDialog.cpp" line="192"/>
+        <location filename="../../LoginDialog.cpp" line="236"/>
         <source>Password is required</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../LoginDialog.cpp" line="209"/>
+        <location filename="../../LoginDialog.cpp" line="253"/>
         <source>For verification, please, enter your password again</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../LoginDialog.cpp" line="222"/>
+        <location filename="../../LoginDialog.cpp" line="266"/>
         <source>Invalid password, please enter again</source>
         <translation type="unfinished"></translation>
     </message>
@@ -350,12 +365,12 @@
 <context>
     <name>RenameGroupDialog</name>
     <message>
-        <location filename="../eWallet.cpp" line="53"/>
+        <location filename="../../eWallet.cpp" line="48"/>
         <source>Save &amp;&amp; Close</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="66"/>
+        <location filename="../../eWallet.cpp" line="61"/>
         <source>Name</source>
         <translation type="unfinished"></translation>
     </message>
@@ -363,131 +378,138 @@
 <context>
     <name>eWallet</name>
     <message>
-        <location filename="../eWallet.cpp" line="410"/>
+        <location filename="../../eWallet.cpp" line="438"/>
         <source>Are you sure you want to remove all your data? You will lost all your data</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="435"/>
+        <location filename="../../eWallet.cpp" line="463"/>
         <source>Wrong password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="639"/>
+        <location filename="../../eWallet.cpp" line="360"/>
+        <location filename="../../eWallet.cpp" line="679"/>
         <source>&lt;All&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="719"/>
+        <location filename="../../eWallet.cpp" line="379"/>
+        <location filename="../../eWallet.cpp" line="688"/>
+        <source>&lt;No Group&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../../eWallet.cpp" line="765"/>
         <source>About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="721"/>
+        <location filename="../../eWallet.cpp" line="767"/>
         <source>Delete DB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="723"/>
-        <location filename="../eWallet.cpp" line="736"/>
+        <location filename="../../eWallet.cpp" line="769"/>
+        <location filename="../../eWallet.cpp" line="780"/>
         <source>Exit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="726"/>
+        <location filename="../../eWallet.cpp" line="772"/>
         <source>New</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="728"/>
-        <location filename="../eWallet.cpp" line="1177"/>
+        <location filename="../../eWallet.cpp" line="774"/>
+        <location filename="../../eWallet.cpp" line="1248"/>
         <source>Edit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="729"/>
+        <location filename="../../eWallet.cpp" line="775"/>
         <source>Invert Sort</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="730"/>
+        <location filename="../../eWallet.cpp" line="776"/>
         <source>Import</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="731"/>
+        <location filename="../../eWallet.cpp" line="777"/>
         <source>Export</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="734"/>
+        <location filename="../../eWallet.cpp" line="779"/>
         <source>Change Password</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="795"/>
+        <location filename="../../eWallet.cpp" line="839"/>
         <source>Are you sure you want to remove it?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="941"/>
+        <location filename="../../eWallet.cpp" line="987"/>
         <source>Choose import file</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="943"/>
-        <location filename="../eWallet.cpp" line="1192"/>
+        <location filename="../../eWallet.cpp" line="989"/>
+        <location filename="../../eWallet.cpp" line="1264"/>
         <source>Text files (*.txt);;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="1166"/>
+        <location filename="../../eWallet.cpp" line="1237"/>
         <source>Rename</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="1167"/>
-        <location filename="../eWallet.cpp" line="1180"/>
+        <location filename="../../eWallet.cpp" line="1238"/>
+        <location filename="../../eWallet.cpp" line="1251"/>
         <source>Delete</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="1176"/>
+        <location filename="../../eWallet.cpp" line="1247"/>
         <source>View</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="1178"/>
+        <location filename="../../eWallet.cpp" line="1249"/>
         <source>New like this</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="1179"/>
+        <location filename="../../eWallet.cpp" line="1250"/>
         <source>Duplicate</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="1190"/>
+        <location filename="../../eWallet.cpp" line="1262"/>
         <source>Choose export file</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="1389"/>
+        <location filename="../../eWallet.cpp" line="1468"/>
         <source>About Wallet</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="1424"/>
+        <location filename="../../eWallet.cpp" line="1503"/>
         <source>Changing password, please wait until application quits</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="1430"/>
+        <location filename="../../eWallet.cpp" line="1509"/>
         <source>Password changed successfully, application will exit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../eWallet.cpp" line="1432"/>
+        <location filename="../../eWallet.cpp" line="1511"/>
         <source>Password CANNOT BE changed, because %1, and application will exit</source>
         <translation type="unfinished"></translation>
     </message>
